import { forwardRef, useEffect } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import useEventListener from '@s-ui/react-hooks/lib/useEventListener';
import { ANIMATION_DURATION, PLACEMENTS, SIZES } from './settings';
import { jsx as _jsx } from "react/jsx-runtime";
var MoleculeDrawer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$animationDuratio = _ref.animationDuration,
      animationDuration = _ref$animationDuratio === void 0 ? ANIMATION_DURATION.FAST : _ref$animationDuratio,
      children = _ref.children,
      _ref$isOpen = _ref.isOpen,
      isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
      onOpen = _ref.onOpen,
      onClose = _ref.onClose,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? PLACEMENTS.LEFT : _ref$placement,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.AUTO : _ref$size,
      target = _ref.target,
      _ref$closeOnOutsideCl = _ref.closeOnOutsideClick,
      closeOnOutsideClick = _ref$closeOnOutsideCl === void 0 ? false : _ref$closeOnOutsideCl;
  useEffect(function () {
    if (target !== undefined) {
      target.current.style.position = 'relative';
      target.current.style.overflow = 'hidden';
    }
  }, [target]);
  useEventListener('keydown', function (event) {
    if (isOpen === false) return;
    event.preventDefault();

    if (event.key === 'Escape') {
      onClose(event, {
        isOpen: false
      });
    }
  });
  useEventListener('mousedown', function (event) {
    if (isOpen === false || !forwardedRef || !closeOnOutsideClick) return;

    if (!forwardedRef.current.contains(event.target)) {
      onClose(event, {
        isOpen: false
      });
    }
  });
  return /*#__PURE__*/_jsx("div", {
    className: cx('react-MoleculeDrawer-content', "react-MoleculeDrawer-content--placement-" + placement, "react-MoleculeDrawer-content--size-" + size, "react-MoleculeDrawer-content--animationDuration-" + animationDuration, "react-MoleculeDrawer-content--state-" + (isOpen ? 'opened' : 'closed'), {
      'react-MoleculeDrawer-content--placement': typeof target === 'undefined'
    }),
    ref: forwardedRef,
    children: children
  });
});
MoleculeDrawer.displayName = 'MoleculeDrawer';
export default MoleculeDrawer;